/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { TOGGLE_ELEMENT } from '../../support/angular.util';

export class UserSettingsE2EComponent {
  private readonly rootLocator: string = 'user-settings';
  private readonly emailBenachrichtigungNewVorgangLocator: string = 'email-benachrichtigung-neuer-Vorgang';
  private readonly emailBenachrichtigungVorgangAssignedToUserLocator: string = 'email-benachrichtigung-neuer-Vorgang-Assigned';
  private readonly emailBenachrichtigungPostfachNachrichtFromAntragsteller: string =
    'email-benachrichtigung-neue-Nachricht-Antragsteller';
  private readonly emailBenachrichtigungWiedervorlageDueToday: string = 'email-benachrichtigung-Faellige-Wiedervorlage';
  private readonly darkModeLocator: string = 'dark-mode';
  private readonly buttonLocator: string = 'user-settings-button';

  public getRoot() {
    return cy.getTestElementWithOid(this.rootLocator);
  }

  public getEmailBenachrichtigungForNewVorgang(): ToggleE2EComponent {
    return new ToggleE2EComponent(this.emailBenachrichtigungNewVorgangLocator);
  }

  public getEmailBenachrichtigungForVorgangAssignedToUser(): ToggleE2EComponent {
    return new ToggleE2EComponent(this.emailBenachrichtigungVorgangAssignedToUserLocator);
  }

  public getEmailBenachrichtigungForPostfachNachrichtFromAntragsteller(): ToggleE2EComponent {
    return new ToggleE2EComponent(this.emailBenachrichtigungPostfachNachrichtFromAntragsteller);
  }

  public getEmailBenachrichtigungForWiedervorlageDueToday(): ToggleE2EComponent {
    return new ToggleE2EComponent(this.emailBenachrichtigungWiedervorlageDueToday);
  }

  public getDarkMode(): ToggleE2EComponent {
    return new ToggleE2EComponent(this.darkModeLocator);
  }

  public getButton() {
    return this.getRoot().getTestElementWithOid(this.buttonLocator);
  }
}

export class ToggleE2EComponent {
  private readonly rootLocator: string;

  constructor(root: string) {
    this.rootLocator = root;
  }

  public getRoot() {
    return cy.getTestElementWithOid(this.rootLocator);
  }

  public getToggle() {
    return this.getRoot().findElement(TOGGLE_ELEMENT);
  }
}
