/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { VorgangBescheidWizardE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-bescheid-wizard.e2e.component';
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import {
  VorgangE2E,
  VorgangStatusE2E,
  vorgangStatusLabelE2E,
} from 'apps/alfa-e2e/src/model/vorgang';
import { uploadFile } from 'apps/alfa-e2e/src/support/file-upload';
import { getAdjustedDateGerman } from 'apps/alfa-e2e/src/support/tech.util';
import 'cypress-real-events/support';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { contains, exist, haveText, notExist } from '../../../support/cypress.util';
import {
  TEST_FILE_BESCHEID_ANHANG_VALID,
  TEST_FILE_BESCHEID_VALID,
} from '../../../support/data.util';
import { initUsermanagerUsers, loginAsSabine } from '../../../support/user-util';
import { buildVorgang, initVorgaenge, objectIds } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang - Bescheid abbrechen', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const bewilligtText: string = 'Bewilligt am';
  const abgelehntText: string = 'Abgelehnt am';
  const stepCaption2: string = 'Dokumente hinzufügen';

  const vorgangPage: VorgangPage = new VorgangPage();
  const bescheidWizard: VorgangBescheidWizardE2EComponent = vorgangPage.getBescheidWizard();

  const bescheidVorgang: VorgangE2E = {
    ...buildVorgang(objectIds[0], 'Wizard Vorgang'),
    status: VorgangStatusE2E.IN_BEARBEITUNG,
  };

  const vorgangFormularButtons: VorgangFormularButtonsE2EComponent =
    vorgangPage.getFormularButtons();

  before(() => {
    initVorgaenge([bescheidVorgang]);
    initUsermanagerUsers();

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe.skip('Sollte gefixt sein nach OZG-6185 - Discard changes after click on Verwerfen', () => {
    it('should click abgelehnt, enter date, and continue to step 2', () => {
      vorgangList.getListItem(bescheidVorgang.name).getRoot().click();
      waitForSpinnerToDisappear();

      vorgangFormularButtons.getBescheidenButton().click();
      bescheidWizard.ablehnen();
      bescheidWizard.enterDate(-1);
      bescheidWizard.weiter();

      bescheidWizard.isBescheidDocumentsStep();
    });

    it('should upload files and continue to step 3', () => {
      bescheidWizard.uploadBescheid(TEST_FILE_BESCHEID_VALID);
      bescheidWizard.bescheidUploadSpinnerIsClosed();
      bescheidWizard.uploadAttachment(TEST_FILE_BESCHEID_ANHANG_VALID);
      bescheidWizard.attachmentSpinnerIsClosed();
      bescheidWizard.weiter();

      bescheidWizard.isBescheidVersendenStep();
    });

    it('should open dialog after click on X', () => {
      bescheidWizard.close();

      bescheidWizard.closeDialogIsShown();
    });

    it('should close Wizard after click on Verwerfen', () => {
      bescheidWizard.getCloseVerwerfenButton().click();
      waitForSpinnerToDisappear();

      bescheidWizard.isClosed();
    });

    it('should show status In Bearbeitung', () => {
      haveText(
        vorgangPage.getVorgangDetailHeader().getStatus(),
        vorgangStatusLabelE2E[VorgangStatusE2E.IN_BEARBEITUNG],
      );
    });
  });

  describe('Keep changes after click on Entwurf speichern', () => {
    it('click Vorgang', () => {
      vorgangList.getListItem(bescheidVorgang.name).getRoot().click();
      waitForSpinnerToDisappear();
    });

    it('should have default Bescheid status and continue to step 2', () => {
      vorgangFormularButtons.getBescheidenButton().click();
      contains(bescheidWizard.getStatusText(), bewilligtText + ' ' + getAdjustedDateGerman(0));
      bescheidWizard.weiter();
    });

    it('should not show file from previous Bescheid', () => {
      notExist(bescheidWizard.getFileAnhangValidInWizard());
      notExist(bescheidWizard.getFileBescheidValidInWizard());
    });

    it('should upload Bescheid and attachment', () => {
      uploadFile(bescheidWizard.getUploadBescheidButton(), TEST_FILE_BESCHEID_VALID);
      notExist(bescheidWizard.getBescheidUploadSpinner());
      uploadFile(bescheidWizard.getUploadAttachmentButton(), TEST_FILE_BESCHEID_ANHANG_VALID);
      notExist(bescheidWizard.getAttachmentUploadSpinner());
    });
    it('should open dialog after click on X', () => {
      bescheidWizard.close();
      exist(bescheidWizard.getCloseDialog());
    });

    it('should close Wizard after click on Speichern', () => {
      bescheidWizard.getCloseSpeichernButton().click();
      waitForSpinnerToDisappear();
      notExist(bescheidWizard.getRoot());
    });

    it('should show status In Bearbeitung', () => {
      haveText(
        vorgangPage.getVorgangDetailHeader().getStatus(),
        vorgangStatusLabelE2E[VorgangStatusE2E.IN_BEARBEITUNG],
      );
    });

    it('should keep date and status from current Bescheid in progress', () => {
      vorgangFormularButtons.getBescheidenButton().click();
      contains(bescheidWizard.getStatusText(), bewilligtText + ' ' + getAdjustedDateGerman(0));
    });

    it('should keep files from current Bescheid in progress', () => {
      bescheidWizard.weiter();
      exist(bescheidWizard.getFileAnhangValidInWizard());
      exist(bescheidWizard.getFileBescheidValidInWizard());
    });
  });
});
