/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { CurrentUserProfileE2EComponent } from 'apps/alfa-e2e/src/components/user-profile/current-user-profile.component.e2e';
import { VorgangListE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-list.e2e.component';
import {
  VorgangViewE2EComponent,
  VorgangViewsE2EComponent,
} from 'apps/alfa-e2e/src/components/vorgang/vorgang-views.e2e.component';
import { UserE2E } from 'apps/alfa-e2e/src/model/user';
import { VorgangE2E, VorgangStatusE2E } from 'apps/alfa-e2e/src/model/vorgang';
import { HeaderE2EComponent } from 'apps/alfa-e2e/src/page-objects/header.po';
import { MainPage, waitForSpinnerToDisappear } from 'apps/alfa-e2e/src/page-objects/main.po';
import { dropCollections } from 'apps/alfa-e2e/src/support/cypress-helper';
import { containClass, exist } from 'apps/alfa-e2e/src/support/cypress.util';
import { getUserSabine, loginAsSabine, loginByUi } from 'apps/alfa-e2e/src/support/user-util';
import { createVorgang, initVorgang } from 'apps/alfa-e2e/src/support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang search view', () => {
  const mainPage: MainPage = new MainPage();

  const header: HeaderE2EComponent = mainPage.getHeader();
  const currentUserProfile: CurrentUserProfileE2EComponent = header.getCurrentUserProfile();

  const views: VorgangViewsE2EComponent = mainPage.getViews();
  const sucheView: VorgangViewE2EComponent = views.getSuche();

  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const user: UserE2E = getUserSabine();

  const vorgang: VorgangE2E = {
    ...createVorgang(),
    name: 'VorgangToAppear',
    status: VorgangStatusE2E.NEU,
  };

  before(() => {
    initVorgang(vorgang);

    loginAsSabine();

    waitForSpinnerToDisappear();
  });

  after(() => {
    dropCollections();
  });

  describe('should select search view', () => {
    it('should set selected after click', () => {
      sucheView.getRoot().click();
      waitForSpinnerToDisappear();

      containClass(sucheView.getRoot(), 'selected');
    });

    it('should show new view after logout and login', () => {
      currentUserProfile.logout();

      loginByUi(user);
      waitForSpinnerToDisappear();

      exist(views.getNeu().getRoot());
    });

    it('should show list after click on NEU view', () => {
      views.getNeu().getRoot().click();
      waitForSpinnerToDisappear();

      exist(vorgangList.getRoot());
    });
  });
});
