/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AdminOrganisationsEinheitResource, OrganisationsEinheitFormContainerComponent } from '@admin-client/admin-settings';
import { StateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, existsAsHtmlElement, getElementFromFixture, getMockComponent, mock } from '@alfa-client/test-utils';
import { SpinnerComponent } from '@alfa-client/ui';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { createAdminOrganisationsEinheitResource } from '../../../../test/organisations-einheit/organisations-einheit';
import { OrganisationsEinheitService } from '../organisationseinheit.service';
import { OrganisationsEinheitFormComponent } from './organisationseinheit-form/organisationseinheit-form.component';

describe('OrganisationsEinheitFormContainerComponent', () => {
  let component: OrganisationsEinheitFormContainerComponent;
  let fixture: ComponentFixture<OrganisationsEinheitFormContainerComponent>;
  let organisationsEinheitService: Mock<OrganisationsEinheitService>;

  const organisationsEinheitResource: AdminOrganisationsEinheitResource = createAdminOrganisationsEinheitResource();
  const organisationsEinheitStateResource: StateResource<AdminOrganisationsEinheitResource> =
    createStateResource(organisationsEinheitResource);

  const headlineSelector: string = getDataTestIdOf('organisations-form-container-headline');
  const formSelector: string = getDataTestIdOf('organisations-form');

  beforeEach(async () => {
    organisationsEinheitService = {
      ...mock(OrganisationsEinheitService),
      get: jest.fn().mockReturnValue(of(organisationsEinheitStateResource)),
    };

    await TestBed.configureTestingModule({
      declarations: [
        OrganisationsEinheitFormContainerComponent,
        MockComponent(OrganisationsEinheitFormComponent),
        MockComponent(SpinnerComponent),
      ],
      providers: [{ provide: OrganisationsEinheitService, useValue: organisationsEinheitService }],
    }).compileComponents();

    fixture = TestBed.createComponent(OrganisationsEinheitFormContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('ngOnInit', () => {
      it('should call organisationsEinheitService get', (done) => {
        component.ngOnInit();

        component.organisationsEinheitStateResource$.subscribe(() => {
          expect(organisationsEinheitService.get).toHaveBeenCalled();
          done();
        });
      });

      it('should set organisationsEinheitStateResource', (done) => {
        component.ngOnInit();

        component.organisationsEinheitStateResource$.subscribe(
          (organisationsEinheitStateResource: StateResource<AdminOrganisationsEinheitResource>) => {
            expect(organisationsEinheitStateResource).toEqual(organisationsEinheitStateResource);
            done();
          },
        );
      });
    });
  });

  describe('template', () => {
    describe('headline', () => {
      it('should show headline', () => {
        existsAsHtmlElement(fixture, headlineSelector);
      });

      it('should show organisationsEinheit name', () => {
        const headlineElement: HTMLElement = getElementFromFixture(fixture, headlineSelector);

        expect(headlineElement.textContent).toBe(organisationsEinheitResource.name);
      });
    });

    describe('organisationsEinheit form', () => {
      it('should show form', () => {
        existsAsHtmlElement(fixture, formSelector);
      });

      it('should have organisationsEinheitStateResource', () => {
        const formComponent: OrganisationsEinheitFormComponent = getMockComponent(fixture, OrganisationsEinheitFormComponent);
        expect(formComponent.organisationsEinheitStateResource).toBe(organisationsEinheitStateResource);
      });
    });
  });
});
