/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidResource, BescheidService } from '@alfa-client/bescheid-shared';
import { tapOnCommandSuccessfullyDone } from '@alfa-client/command-shared';
import { StateResource, isNotNil } from '@alfa-client/tech-shared';
import { DIALOG_DATA, DialogRef } from '@angular/cdk/dialog';
import { Component, Inject } from '@angular/core';
import { Resource } from '@ngxp/rest';
import { Observable } from 'rxjs';
import { BescheidFormService } from '../../bescheid.formservice';

export interface CancelWizardDialogData {
  bescheidResource: BescheidResource;
}

export interface CancelWizardDialogResult {
  closeWizard: boolean;
}

@Component({
  templateUrl: './bescheid-wizard-cancel-dialog-container.component.html',
})
export class BescheidWizardCancelDialogContainerComponent {
  public saveStateResource$: Observable<StateResource<Resource>>;
  public deleteStateResource$: Observable<StateResource<Resource>>;

  bescheidResource: BescheidResource;

  constructor(
    @Inject(DIALOG_DATA) readonly dialogData: CancelWizardDialogData,
    public dialogRef: DialogRef<CancelWizardDialogResult>,
    private readonly bescheidService: BescheidService,
    private readonly formService: BescheidFormService,
  ) {
    this.bescheidResource = dialogData.bescheidResource;
  }

  public save(): void {
    this.saveStateResource$ = this.formService.submit().pipe(tapOnCommandSuccessfullyDone(() => this.closeDialogWithWizard()));
  }

  public cancel(): void {
    if (isNotNil(this.bescheidResource)) {
      this.deleteStateResource$ = this.bescheidService
        .bescheidVerwerfen()
        .pipe(tapOnCommandSuccessfullyDone(() => this.closeDialogWithWizard()));
    } else {
      this.closeDialogWithWizard();
    }
  }

  closeDialogWithWizard(): void {
    this.dialogRef.close({ closeWizard: true });
  }
}
