/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { convertForDataTest } from '@alfa-client/tech-shared';
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormControl, ReactiveFormsModule } from '@angular/forms';
import { faker } from '@faker-js/faker';
import { getDataTestIdOf } from '../../../../../tech-shared/test/data-test';
import { TextInputComponent } from './text-input.component';

describe('TextInputComponent', () => {
  let component: TextInputComponent;
  let fixture: ComponentFixture<TextInputComponent>;
  const label: string = faker.word.noun();
  const dataTestId: string = `${convertForDataTest(label)}-text-input`;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ReactiveFormsModule, TextInputComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(TextInputComponent);
    component = fixture.componentInstance;
    component.label = label;
    component.fieldControl = new FormControl();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('aria', () => {
    it('should have aria-invalid attribute', () => {
      component.variant = 'error';

      fixture.detectChanges();

      const element: HTMLElement = getElementFromFixture(fixture, getDataTestIdOf(dataTestId));
      expect(element.hasAttribute('aria-invalid')).toBe(true);
    });

    it('should have aria-invalid value false', () => {
      component.variant = 'default';

      fixture.detectChanges();

      const element: HTMLElement = getElementFromFixture(fixture, getDataTestIdOf(dataTestId));
      expect(element.getAttribute('aria-invalid')).toEqual('false');
    });

    it('should have aria-invalid value true', () => {
      component.variant = 'error';

      fixture.detectChanges();

      const element: HTMLElement = getElementFromFixture(fixture, getDataTestIdOf(dataTestId));
      expect(element.getAttribute('aria-invalid')).toEqual('true');
    });
  });

  describe('focus', () => {
    beforeEach(() => {
      component.inputElement.nativeElement.focus = jest.fn();
    });

    it('should focus', () => {
      component.focus = true;

      expect(component.inputElement.nativeElement.focus).toHaveBeenCalled();
    });

    it('should not focus', () => {
      component.focus = false;

      expect(component.inputElement.nativeElement.focus).not.toHaveBeenCalled();
    });
  });
});
