/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  createHintListResource,
  createHintListResourceWithResource,
  createHintResource,
} from 'libs/hint-shared/test/hint';
import { HintMessageCode } from './hint.message';
import { HintResource } from './hint.model';
import {
  hasUserNoOrganisationsEinheitIdHint,
  isUserHasNoOrganisationsEinheitIdHint,
} from './hint.util';

describe('Hint Util', () => {
  describe('isUserHasNoOrganisationsEinheitIdHint', () => {
    it('should return true if code match', () => {
      const result: boolean = isUserHasNoOrganisationsEinheitIdHint({
        ...createHintResource(),
        code: HintMessageCode.USER_NO_ORGANISATIONS_EINHEIT_ID,
      });

      expect(result).toBeTruthy();
    });
  });

  describe('hasUserNoOrganisationsEinheitIdHint', () => {
    it('should return resource if code match', () => {
      const hint: HintResource = {
        ...createHintResource(),
        code: HintMessageCode.USER_NO_ORGANISATIONS_EINHEIT_ID,
      };

      const hasUser: boolean = hasUserNoOrganisationsEinheitIdHint(
        createHintListResourceWithResource([hint]),
      );

      expect(hasUser).toBeTruthy();
    });

    it('should return false if code NOT match', () => {
      const hasUser: boolean = hasUserNoOrganisationsEinheitIdHint(createHintListResource());

      expect(hasUser).toBeFalsy();
    });
  });
});
