/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { HistorieFacade } from '@alfa-client/historie-shared';
import { mock } from '@alfa-client/test-utils';
import { MockComponent } from 'ng-mocks';
import { HistorieContainerComponent } from './historie-container.component';
import { HistorieListComponent } from './historie-list/historie-list.component';

describe('HistorieContainerComponent', () => {
  let component: HistorieContainerComponent;
  let fixture: ComponentFixture<HistorieContainerComponent>;

  const historieFacade = mock(HistorieFacade);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [HistorieContainerComponent, MockComponent(HistorieListComponent)],
      providers: [
        {
          provide: HistorieFacade,
          useValue: historieFacade,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(HistorieContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should load historie', () => {
      component.ngOnInit();

      expect(historieFacade.getHistorie).toHaveBeenCalled();
    });
  });

  describe('ngOnDestroy', () => {
    it('should call facade', () => {
      component.ngOnDestroy();

      expect(historieFacade.reloadHistorie).toHaveBeenCalled();
    });
  });
});
