/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Bescheid } from '@alfa-client/bescheid-shared';
import { CommandOrder, CommandResource } from '@alfa-client/command-shared';
import { StringBasedKeyMap } from '@alfa-client/tech-shared';
import { Component, Input } from '@angular/core';

@Component({
  selector: 'alfa-historie-item-bescheid',
  templateUrl: './historie-item-bescheid.component.html',
  styleUrls: ['./historie-item-bescheid.component.scss'],
})
export class HistorieItemBescheidComponent {
  @Input() command: CommandResource;

  headline: string;
  hasBody: boolean = true;

  get bescheid(): Bescheid {
    return this.command.body;
  }

  ngOnInit(): void {
    this.headline = HISTORIE_TEXT_BY_BESCHEID_ORDER[this.command.order];
    this.hasBody = this.hasCommandBody();
  }

  private hasCommandBody(): boolean {
    return this.command.order == CommandOrder.UPDATE_BESCHEID;
  }
}

const HISTORIE_TEXT_BY_BESCHEID_ORDER: StringBasedKeyMap<string> = {
  [CommandOrder.SEND_BESCHEID]: 'einen Bescheid per Nachricht verschickt.',
  [CommandOrder.UPDATE_BESCHEID]: 'einen Bescheid erstellt.',
};
