/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createEmptyStateResource } from '@alfa-client/tech-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MatIcon } from '@angular/material/icon';
import { MatMenuModule } from '@angular/material/menu';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MockComponent, MockModule } from 'ng-mocks';
import { SpinnerComponent } from '../spinner/spinner.component';
import { IconButtonWithSpinnerComponent } from './icon-button-with-spinner.component';

describe('IconButtonWithSpinnerComponent', () => {
  let component: IconButtonWithSpinnerComponent;
  let fixture: ComponentFixture<IconButtonWithSpinnerComponent>;

  const buttonSelector = '[data-test-class="icon-button"]';
  const iconSelector = '[data-test-class="icon"]';

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        IconButtonWithSpinnerComponent,
        MatIcon,
        MockComponent(SpinnerComponent),
        MockModule(MatTooltipModule),
        MockModule(MatMenuModule),
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(IconButtonWithSpinnerComponent);
    component = fixture.componentInstance;
    component.icon = 'edit';

    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('Button', () => {
    it('should NOT disabled initial', () => {
      const button = fixture.nativeElement.querySelector(buttonSelector);
      component.stateResource = createEmptyStateResource();
      fixture.detectChanges();

      expect(button).not.toBeDisabled();
    });

    it('should disabled if loading', () => {
      const button = fixture.nativeElement.querySelector(buttonSelector);
      component.stateResource = createEmptyStateResource(true);
      fixture.detectChanges();

      expect(button).toBeDisabled();
    });
  });

  describe('Icon', () => {
    it('should visible initial', () => {
      const icon = fixture.nativeElement.querySelector(iconSelector);
      component.stateResource = createEmptyStateResource();
      fixture.detectChanges();

      expect(icon).toBeVisible();
    });

    it('should not visible if loading', () => {
      const icon = fixture.nativeElement.querySelector(iconSelector);
      component.stateResource = createEmptyStateResource(true);
      fixture.detectChanges();

      expect(icon).not.toBeVisible();
    });
  });
});
