/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { mock } from '@alfa-client/test-utils';
import { IconButtonWithSpinnerComponent } from '@alfa-client/ui';
import { UserProfileService } from '@alfa-client/user-profile-shared';
import { VorgangHeaderLinkRel } from '@alfa-client/vorgang-shared';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { AssignUserProfileButtonContainerComponent } from './assign-user-profile-button-container.component';

describe('AssignUserProfileButtonContainerComponent', () => {
  let component: AssignUserProfileButtonContainerComponent;
  let fixture: ComponentFixture<AssignUserProfileButtonContainerComponent>;

  const assignUserProfileButton: string = '[data-test-id="assign-user-profile-icon-button"]';

  const userProfileService = mock(UserProfileService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        AssignUserProfileButtonContainerComponent,
        HasLinkPipe,
        MockComponent(IconButtonWithSpinnerComponent),
      ],
      providers: [
        {
          provide: UserProfileService,
          useValue: userProfileService,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AssignUserProfileButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('button', () => {
    it('should be visible', () => {
      component.vorgang = createVorgangWithEingangResource([VorgangHeaderLinkRel.ASSIGN]);
      fixture.detectChanges();

      const button = fixture.nativeElement.querySelector(assignUserProfileButton);

      expect(button).toBeInstanceOf(HTMLElement);
    });

    it('should be hidden', () => {
      component.vorgang = createVorgangWithEingangResource();
      fixture.detectChanges();

      const button = fixture.nativeElement.querySelector(assignUserProfileButton);

      expect(button).not.toBeInstanceOf(HTMLElement);
    });
  });

  describe('showUserProfileSearch', () => {
    it('should call service', () => {
      component.showUserProfileSearch();

      expect(userProfileService.showUserProfileSearch).toHaveBeenCalled();
    });
  });
});
