/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidLinkRel, BescheidService } from '@alfa-client/bescheid-shared';
import { createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { VorgangService, VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { cold } from 'jest-marbles';
import { EMPTY, of } from 'rxjs';
import { createBescheidResource } from '../../../../../../../bescheid-shared/src/test/bescheid';
import { createVorgangWithEingangResource } from '../../../../../../../vorgang-shared/test/vorgang';
import { BescheidenFormService } from '../../bescheiden.formservice';
import { VorgangDetailBescheidenWeiterButtonComponent } from './vorgang-detail-bescheiden-weiter-button.component';

describe('VorgangDetailBescheidenWeiterButtonComponent', () => {
  let component: VorgangDetailBescheidenWeiterButtonComponent;
  let fixture: ComponentFixture<VorgangDetailBescheidenWeiterButtonComponent>;

  let formService: Mock<BescheidenFormService>;
  let bescheidService: Mock<BescheidService>;
  let vorgangService: Mock<VorgangService>;

  beforeEach(async () => {
    formService = mock(BescheidenFormService);
    bescheidService = mock(BescheidService);
    vorgangService = mock(VorgangService);
    bescheidService.getBescheidDraftIfExists.mockReturnValue(EMPTY);
    vorgangService.getVorgangWithEingang.mockReturnValue(EMPTY);

    await TestBed.configureTestingModule({
      declarations: [VorgangDetailBescheidenWeiterButtonComponent],
      providers: [
        {
          provide: BescheidenFormService,
          useValue: formService,
        },
        {
          provide: BescheidService,
          useValue: bescheidService,
        },
        {
          provide: VorgangService,
          useValue: vorgangService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangDetailBescheidenWeiterButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should show button if update link available', () => {
      const bescheidResource = createBescheidResource([BescheidLinkRel.UPDATE]);
      bescheidService.getBescheidDraftIfExists.mockReturnValue(
        of(createStateResource(bescheidResource)),
      );

      component.ngOnInit();

      expect(component.showButton$).toBeObservable(cold('(a|)', { a: true }));
    });

    it('should not show button if update link unavailable', () => {
      const bescheidResource = createBescheidResource();
      bescheidService.getBescheidDraftIfExists.mockReturnValue(
        of(createStateResource(bescheidResource)),
      );

      component.ngOnInit();

      expect(component.showButton$).toBeObservable(cold('(a|)', { a: false }));
    });

    it('should show button if create bescheid draft link available', () => {
      const vorgangWithEingangResource = createVorgangWithEingangResource([
        VorgangWithEingangLinkRel.CREATE_BESCHEID_DRAFT,
      ]);
      vorgangService.getVorgangWithEingang.mockReturnValue(
        of(createStateResource(vorgangWithEingangResource)),
      );

      component.ngOnInit();

      expect(component.showButton$).toBeObservable(cold('(a|)', { a: true }));
    });
  });
});
