/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { StateResource } from '@alfa-client/tech-shared';
import {
  VorgangService,
  VorgangWithEingangLinkRel,
  VorgangWithEingangResource,
} from '@alfa-client/vorgang-shared';
import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { Observable, tap } from 'rxjs';

@Component({
  selector: 'alfa-vorgang-export-container',
  templateUrl: './vorgang-export-container.component.html',
  styleUrls: ['./vorgang-export-container.component.scss'],
})
export class VorgangExportContainerComponent implements OnInit {
  @Input() vorgangWithEingang: VorgangWithEingangResource;

  @Output() public closeMenu: EventEmitter<void> = new EventEmitter();

  public exportStateResource$: Observable<StateResource<boolean>>;
  public canExport: boolean = false;

  constructor(private vorgangService: VorgangService) {}

  ngOnInit(): void {
    this.exportStateResource$ = this.vorgangService
      .getVorgangExport()
      .pipe(tap((vorgangExportStateResource) => this.isExportDone(vorgangExportStateResource)));
  }

  isExportDone(vorgangExportStateResource: StateResource<boolean>): void {
    if (vorgangExportStateResource.resource) this.closeMenu.emit();
  }

  public export(): void {
    this.vorgangService.export(this.vorgangWithEingang);
  }

  readonly vorgangWithEingangLinkRel = VorgangWithEingangLinkRel;
}
