/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.attacheditem;

import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.alfa.common.GrpcUtil;
import de.ozgcloud.alfa.common.errorhandling.ResourceNotFoundException;
import de.ozgcloud.vorgang.vorgangAttachedItem.GrpcFindVorgangAttachedItemRequest;
import de.ozgcloud.vorgang.vorgangAttachedItem.GrpcVorgangAttachedItemRequest;
import de.ozgcloud.vorgang.vorgangAttachedItem.GrpcVorgangAttachedItemResponse;
import de.ozgcloud.vorgang.vorgangAttachedItem.VorgangAttachedItemServiceGrpc.VorgangAttachedItemServiceBlockingStub;
import io.grpc.Status.Code;
import io.grpc.StatusRuntimeException;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service
class VorgangAttachedItemRemoteService {

	@GrpcClient(GrpcUtil.VORGANG_MANAGER_GRPC_CLIENT)
	private VorgangAttachedItemServiceBlockingStub vorgangAttachedItemServiceStub;

	@Autowired
	private VorgangAttachedItemMapper mapper;

	public Stream<VorgangAttachedItem> findVorgangAttachedItem(String vorgangId, String itemName) {
		var response = vorgangAttachedItemServiceStub.find(buildFindRequest(vorgangId, itemName));

		return response.getVorgangAttachedItemsList().stream().map(mapper::fromGrpc);
	}

	GrpcFindVorgangAttachedItemRequest buildFindRequest(String vorgangId, String itemName) {
		return GrpcFindVorgangAttachedItemRequest.newBuilder()
				.setVorgangId(vorgangId)
				.setItemName(itemName)
				.build();
	}

	public VorgangAttachedItem getById(String id) {
		var response = doGetById(id);

		return mapper.fromGrpc(response.getVorgangAttachedItem());
	}

	GrpcVorgangAttachedItemResponse doGetById(String id) {
		try {
			return vorgangAttachedItemServiceStub.getById(buildGetByIdRequest(id));
		} catch (StatusRuntimeException e) {
			if (e.getStatus().getCode() == Code.NOT_FOUND) {
				throw new ResourceNotFoundException(VorgangAttachedItem.class, id);
			}
			throw e;
		}
	}

	GrpcVorgangAttachedItemRequest buildGetByIdRequest(String id) {
		return GrpcVorgangAttachedItemRequest.newBuilder().setId(id).build();
	}
}