/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.user;

import java.util.Optional;
import java.util.function.Predicate;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.util.UriComponentsBuilder;

import de.ozgcloud.alfa.postfach.PostfachMail;

@Service
public class UserManagerUrlProvider {

	public static final String SYSTEM_USER_IDENTIFIER = "system";
	public static final Predicate<PostfachMail> SENT_BY_CLIENT_USER = postfachNachricht -> Optional.ofNullable(postfachNachricht.getCreatedBy())
			.map(createdBy -> !createdBy.toString().startsWith(SYSTEM_USER_IDENTIFIER)).orElse(false);

	@Autowired
	private UserManagerProperties userManagerProperties;

	/** only for building links */
	public String getUserProfileTemplate() {
		return userManagerProperties.getUrl() + userManagerProperties.getProfileTemplate();
	}

	public UriComponentsBuilder getSearchUserProfilesTemplate() {
		return UriComponentsBuilder.fromUriString(userManagerProperties.getUrl() + userManagerProperties.getSearchTemplate());
	}

	public boolean isConfiguredForUserProfile() {
		return StringUtils.isNotBlank(userManagerProperties.getUrl()) && StringUtils.isNotBlank(userManagerProperties.getProfileTemplate());
	}

	public boolean isConfiguredForSearchUserProfile() {
		return StringUtils.isNotBlank(userManagerProperties.getUrl()) && StringUtils.isNotBlank(userManagerProperties.getSearchTemplate());
	}
}