/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.historie;

import java.util.List;
import java.util.stream.Stream;

import org.springframework.stereotype.Service;

import de.ozgcloud.alfa.common.command.Command;
import de.ozgcloud.alfa.common.command.CommandService;
import de.ozgcloud.alfa.common.user.UserService;
import de.ozgcloud.alfa.vorgang.VorgangWithEingang;
import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
public class VorgangChangeHistoryService {

	private final UserService userService;
	private final CommandService commandService;

	public VorgangChangeHistory createVorgangChangeHistory(VorgangWithEingang vorgang) {
		var commands = commandService.findFinishedCommands(vorgang.getId()).toList();
		return VorgangChangeHistory.builder()
				.statusChangeHistory(createStatusChangeHistory(vorgang, commands).toList())
				.aktenzeichenChangeHistory(createAktenzeichenChangeHistory(vorgang, commands).toList())
				.assignedUserChangeHistory(createAssignedUserChangeHistory(vorgang, commands).toList())
				.build();
	}

	Stream<VorgangChange> createStatusChangeHistory(VorgangWithEingang vorgang, List<Command> commands) {
		return StatusChangeHistoryBuilder.builder()
				.withCommands(commands)
				.withOrganisationseinheitenID(vorgang.getOrganisationseinheitenID())
				.build();
	}

	Stream<VorgangChange> createAktenzeichenChangeHistory(VorgangWithEingang vorgang, List<Command> commands) {
		return AktenzeichenChangeHistoryBuilder.builder()
				.withCommands(commands)
				.withOrganisationseinheitenID(vorgang.getOrganisationseinheitenID())
				.build();
	}

	Stream<VorgangChange> createAssignedUserChangeHistory(VorgangWithEingang vorgang, List<Command> commands) {
		return AssignedUserChangeHistoryBuilder.builder()
				.withCommands(commands)
				.withOrganisationseinheitenID(vorgang.getOrganisationseinheitenID())
				.withUserProfileCache(UserProfileCache.create(userService::getById))
				.build();
	}

}
