/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang.forwarding;

import jakarta.validation.ConstraintValidator;
import jakarta.validation.ConstraintValidatorContext;

import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.alfa.common.ValidationMessageCodes;

class ForwardingPasswordValidator implements ConstraintValidator<ForwardingPasswordSizeConstraint, RedirectRequest> {

	@Autowired
	private ForwardingLandesnetzInfoService landesnetzInfoService;

	@Override
	public boolean isValid(RedirectRequest request, ConstraintValidatorContext context) {
		if (StringUtils.isNotBlank(request.getEmail()) && isNotInLandesnetz(request.getEmail())) {
			prepareConstraint(context);

			return isValidPassword(request);
		}
		return true;
	}

	private boolean isNotInLandesnetz(String email) {
		return !landesnetzInfoService.isEmailInLandesnetz(email);
	}

	boolean isValidPassword(RedirectRequest request) {
		var password = request.getPassword();
		var constraint = request.getClass().getAnnotation(ForwardingPasswordSizeConstraint.class);

		return ArrayUtils.isNotEmpty(password) && password.length >= constraint.min() && password.length <= constraint.max();
	}

	void prepareConstraint(ConstraintValidatorContext context) {
		context.disableDefaultConstraintViolation();
		context.buildConstraintViolationWithTemplate(ValidationMessageCodes.FIELD_SIZE)
				.addPropertyNode("password").addConstraintViolation();
	}
}