/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.collaboration;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Spy;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.IanaLinkRelations;
import org.springframework.hateoas.Link;

class FachstelleModelAssemblerTest {

	@Spy
	private FachstelleModelAssembler assembler;

	@Nested
	class TestToModel {

		@Test
		void shouldHaveSelfLink() {
			var model = assembler.toModel(FachstelleTestFactory.create());

			assertHaveSelfLink(model);
		}

		private void assertHaveSelfLink(EntityModel<Fachstelle> model) {
			assertThat(model.getLink(IanaLinkRelations.SELF_VALUE)).isPresent().get().extracting(Link::getHref)
					.isEqualTo(FachstelleController.PATH + "/" + FachstelleTestFactory.ID);
		}
	}

	@Nested
	class TestToCollectionModel {

		private Fachstelle fachstelle = FachstelleTestFactory.create();

		@Test
		void shouldCallToModel() {
			callAssembler();

			verify(assembler).toModel(fachstelle);
		}

		@Test
		void shouldHaveSelfLink() {
			var model = callAssembler();

			assertThat(model.getLink(IanaLinkRelations.SELF_VALUE)).isPresent().get().extracting(Link::getHref)
					.isEqualTo(FachstelleController.PATH);
		}

		@Test
		void shouldContainEntityModel() {
			var entityModel = EntityModel.of(fachstelle);
			doReturn(entityModel).when(assembler).toModel(fachstelle);

			var model = callAssembler();

			assertThat(model).containsExactly(entityModel);
		}

		private CollectionModel<EntityModel<Fachstelle>> callAssembler() {
			return assembler.toCollectionModel(List.of(fachstelle));
		}
	}
}
