/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.clientattribute;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttribute;

class ClientAttributeUtilsTest {
	private List<GrpcClientAttribute> attributeList;

	@Nested
	class TestFind {
		private GrpcClientAttribute expectedClientAttribute = GrpcClientAttributeTestFactory.create();

		@Test
		void shouldFindOne() {
			attributeList = List.of(
					GrpcClientAttributeTestFactory.createBuilder().setAttributeName("name1").setClientName("client1").build(),
					GrpcClientAttributeTestFactory.createBuilder().setAttributeName(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT.getAttributeName())
							.setClientName(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT.getClientName().toString()).build());

			var resultStream = ClientAttributeUtils.findGrpcValue(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT, attributeList);

			assertThat(resultStream).contains(expectedClientAttribute.getValue());
		}

		@Test
		void shouldNotFindOneDueToClientName() {
			attributeList = List.of(GrpcClientAttributeTestFactory.createBuilder()
					.setAttributeName(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT.getAttributeName())
					.setClientName("client2")
					.build());

			var resultStream = ClientAttributeUtils.findGrpcValue(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT, attributeList);

			assertThat(resultStream).isEmpty();
		}

		@Test
		void shouldNotFindOneDueToAttributeName() {
			attributeList = List.of(GrpcClientAttributeTestFactory.createBuilder()
					.setAttributeName("name2")
					.setClientName(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT.getClientName().toString())
					.build());

			var resultStream = ClientAttributeUtils.findGrpcValue(ClientAttribute.HAS_NEW_POSTFACH_NACHRICHT, attributeList);

			assertThat(resultStream).isEmpty();
		}
	}
}
