/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.alfa.vorgang.VorgangWithEingang;
import de.ozgcloud.alfa.vorgang.VorgangWithEingangTestFactory;

class PostfachNachrichtHelperTest {

	@InjectMocks
	private PostfachNachrichtHelper helper;
	@Mock
	private PostfachMailMapper mapper;

	@DisplayName("Add postfachAddress to body")
	@Nested
	class TestAddPostfachAddressToBody {

		private final PostfachMail postfachNachrichtWithoutPostfachAddress = PostfachMailTestFactory.createBuilder().postfachAddress(null).build();
		private final VorgangWithEingang vorgang = VorgangWithEingangTestFactory.create();

		@BeforeEach
		void mockMapper() {
			when(mapper.mapPostfachAddressToMap(any())).thenReturn(PostfachAddressTestFactory.createAsMap());
		}

		@Test
		void shouldCallMapperWithPostfachAddress() {
			helper.addPostfachAddressToBody(postfachNachrichtWithoutPostfachAddress, vorgang);

			verify(mapper).mapPostfachAddressToMap(vorgang.getHeader().getServiceKonto().getPostfachAddresses().get(0));
		}

		@Test
		void shouldReturn() {
			var body = helper.addPostfachAddressToBody(postfachNachrichtWithoutPostfachAddress, vorgang);

			assertThat(((PostfachMail) body).getPostfachAddress()).usingRecursiveComparison().isEqualTo(PostfachAddressTestFactory.createAsMap());
		}
	}
}
